from urllib import request, parse
from urllib.error import HTTPError

import json

base_url = "https://magiscan.ar-generation.com:5124"

def downloadApikey(filename):
    req = request.Request(
         f"{base_url}/omniverse/apikey",
        method="GET",
    )
    apiKey = request.urlopen(req).read().decode("utf-8")
    
    with open(filename, "w") as f:
        f.write(apiKey)

    return apiKey


def downloadQrCode(apiKey, filename):
    headers = {
        "ApiKey": f"{apiKey}",
    }
    req = request.Request(
        f"{base_url}/omniverse/generate_qr",
        method="GET",
        headers=headers,
    )
    data = request.urlopen(req).read()
    with open(filename, "wb") as f:
        f.write(data)


def load_models(apiKey):
    headers = {
        "ApiKey": f"{apiKey}",
    }
    req = request.Request(
        f"{base_url}/omniverse/models",
        method="GET",
        headers=headers,
    )
    try:
        models = json.loads(request.urlopen(req).read().decode("utf-8"))
    except HTTPError as e:
        if(e.code == 401):
            return "NotLinked"
        else:
            return "NetworkError"
    
    return models


def get_preview_url(path):
    return f"{base_url}/file/{path}"


def get_model_url(modelId, apiKey):
    headers = {
        "ApiKey": f"{apiKey}",
        "ModelId": f"{modelId}",
        "Format": f"usdz",
    }
    req = request.Request(
        f"{base_url}/omniverse/model",
        method="GET",
        headers=headers,
    )
    url = json.loads(request.urlopen(req).read().decode("utf-8"))["url"]
    return f"{base_url}/file/{url}"


def download_file(url, filename):
    req = request.Request(url)
    data = request.urlopen(req).read()

    with open(filename, "wb") as f:
        f.write(data)
